Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var RootCmd = &cobra.Command{ Use: "bbkt", Version: version.Version, Short: "A unified CLI and MCP server for Bitbucket Cloud", Long: `bbkt is a complete command-line interface and Model Context Protocol server for Bitbucket Cloud. It allows you to manage workspaces, repositories, pull requests, pipelines, and more directly from your terminal, or expose these capabilities to your AI agents via the MCP protocol. Try running 'bbkt auth' to get started!`, PersistentPreRun: func(cmd *cobra.Command, args []string) { if profile, _ := cmd.Flags().GetString("profile"); profile != "" { os.Setenv("BBKT_PROFILE", profile) } }, }
RootCmd represents the base command when called without any subcommands
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func ParseArgs ¶
func ParseArgs(args []string, trailingArgsCount int) (workspace, repoSlug string, trailing []string, err error)
ParseArgs resolves workspace and repoSlug from the command line arguments, and returns any remaining trailing arguments. It expects either: - exact trailingArgsCount arguments (infers workspace and repoSlug from git) - trailingArgsCount + 2 arguments (explicit workspace and repoSlug provided first)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.